@@ -1,7 +1,21 @@
-from . import resources, changeset, events, outputs, dashboard, table
+import json
+import botocore
+import time
+from datetime import timedelta
+
+from . import (
+    logger,
+    resources,
+    changeset,
+    events,
+    outputs,
+    dashboard,
+    table,
+    IboxErrorECSService,
+    IboxError,
+)
 from .tags import get_action_tags
 from .tools import show_confirm
-from .common import *
 
 
 # build all args for action
@@ -154,7 +168,10 @@ def update(istack):
     istack.last_event_timestamp = events.get_last_timestamp(istack)
 
     # do stack update
-    response = istack.client.update_stack(**us_args)
+    try:
+        response = istack.client.update_stack(**us_args)
+    except botocore.exceptions.ClientError as err:
+        raise IboxError(err)
     istack.mylog(f"{json.dumps(response)}\n")
     time.sleep(1)
 
