@@ -1,8 +1,10 @@
-from . import resources
-from .common import *
-
+import json
+from pprint import pprint
+from datetime import datetime
 from copy import deepcopy
 
+from . import resources
+
 
 def add_stack(istack):
     widget_width = {
@@ -27,7 +29,7 @@ def add_stack(istack):
     widget_map = {
         "role": ["cpu", "response"],
         "memory": ["memory"],
-        "req": ["requests", "healthy"],
+        "req": ["requests", "elb_net_active_flows", "elb_net_bytes", "healthy"],
         "5xx": ["5xx", "4xx"],
         "5xx_elb": ["5xx_elb", "4xx_elb"],
         "50x_elb": ["500_elb", "502_elb", "503_elb", "504_elb"],
@@ -35,7 +37,6 @@ def add_stack(istack):
     }
 
     ScalingPolicyTrackingsCpuBaseLabel = "ScalingPolicyTrackingsCpu"
-    widget_label = {}
 
     def get_alarm(res):
         alarms = {}
@@ -47,7 +48,7 @@ def add_stack(istack):
         return alarms["AlarmCPUHigh"], alarms["AlarmCPULow"]
 
     def get_policy_ec2(res):
-        polname = res["ScalingPolicyTrackings1"].split("/")[2]
+        polname = res["ScalingPolicyTrackingsEC2"]
         AutoScalingGroupName = (
             "AutoScalingGroupSpotName"
             if "AutoScalingGroupSpotName" in res
@@ -59,22 +60,24 @@ def add_stack(istack):
             PolicyNames=[polname],
         )
 
-        return response["ScalingPolicies"][0]["TargetTrackingConfiguration"]
+        return response["ScalingPolicies"][0].get("TargetTrackingConfiguration", {})
 
     def get_policy_ecs(res):
-        resname = "/".join(res["ScalingPolicyTrackingsApp"].split("/")[2:5]).split(":")[
-            0
-        ]
+        if "ScalingPolicyTrackingsECS" not in res:
+            return {}
+        pol_arn_array = res["ScalingPolicyTrackingsECS"].split("/")
+        polname = pol_arn_array[3]
+        resname = "/".join(pol_arn_array[0:3]).split(":")[0]
         client = istack.boto3.client("application-autoscaling")
         response = client.describe_scaling_policies(
-            PolicyNames=list(istack.cfg.SCALING_POLICY_TRACKINGS_NAMES.keys()),
+            PolicyNames=[polname],
             ResourceId=resname,
             ServiceNamespace="ecs",
         )
 
-        return response["ScalingPolicies"][0][
-            "TargetTrackingScalingPolicyConfiguration"
-        ]
+        return response["ScalingPolicies"][0].get(
+            "TargetTrackingScalingPolicyConfiguration", {}
+        )
 
     def get_policy(res):
         ret = []
@@ -91,7 +94,7 @@ def add_stack(istack):
                 color = "#36dc52"
 
             stat = "Average"
-            value = conf["TargetValue"]
+            value = conf.get("TargetValue", 0)
             if (
                 "CustomizedMetricSpecification" in conf
                 and "Statistic" in conf["CustomizedMetricSpecification"]
@@ -128,7 +131,7 @@ def add_stack(istack):
             AlarmCPUHighThreshold, AlarmCPULowThreshold = get_alarm(res)
             widget_annotations_type = "step"
 
-        if any(k in res for k in istack.cfg.SCALING_POLICY_TRACKINGS_NAMES):
+        if any("ScalingPolicyTrackings" in r for r in res):
             widget_annotations_type = "tracking"
             tracking_list.append({"value": 100})
             for n in get_policy(res):
@@ -273,6 +276,10 @@ def add_stack(istack):
     def update_dashboard(res, dashboard_name):
         cw = istack.boto3.client("cloudwatch")
 
+        if istack.cfg.dash_force and dashboard_name.split("_")[1] == istack.name:
+            # delete dash only before processing the first stack
+            cw.delete_dashboards(DashboardNames=[dashboard_name])
+
         if not istack.cfg.silent:
             print(dashboard_name)
 
@@ -281,7 +288,7 @@ def add_stack(istack):
                 "DashboardBody"
             ]
             dash = json.loads(dashboard_body)
-        except Exception as e:
+        except Exception:
             print("DashBoard do not exist, creating one..\n")
             dash = {"widgets": []}
 
@@ -377,13 +384,22 @@ def add_stack(istack):
 
     def get_metrics(res):
         # update widget_title and widget_label
+        LoadBalancerName = None
+        LoadBalancerNameExternal = None
+        LoadBalancerNameInternal = None
+        AWS_ELB = None
+        Latency = None
+        HTTPCode_Backend_5XX = None
+        HTTPCode_Backend_4XX = None
+
         title_role = f"{istack.EnvRole}.{istack.name}"
         widget_title["role"] = f"{title_role} [Cpu - Response]"
 
-        # Set common variable for ELB Classic and Application used by EC2 stack
+        # Set common variable for ELB Classic and Application
         if any(
             n in res for n in ["LoadBalancerNameExternal", "LoadBalancerNameInternal"]
         ):
+            # Classic
             LoadBalancerName = "LoadBalancerName"
             LoadBalancerNameExternal = "LoadBalancerNameExternal"
             LoadBalancerNameInternal = "LoadBalancerNameInternal"
@@ -393,7 +409,14 @@ def add_stack(istack):
             HTTPCode_Backend_4XX = "HTTPCode_Backend_4XX"
             HTTPCode_ELB_5XX = "HTTPCode_ELB_5XX"
             HTTPCode_ELB_4XX = "HTTPCode_ELB_4XX"
-        elif any(n in res for n in ["LoadBalancerExternal", "LoadBalancerInternal"]):
+        elif any(
+            n in res
+            for n in [
+                "LoadBalancerExternal",
+                "LoadBalancerInternal",
+            ]
+        ):
+            # Application
             LoadBalancerName = "LoadBalancer"
             LoadBalancerNameExternal = "LoadBalancerExternal"
             LoadBalancerNameInternal = "LoadBalancerInternal"
@@ -403,14 +426,19 @@ def add_stack(istack):
             HTTPCode_Backend_4XX = "HTTPCode_Target_4XX_Count"
             HTTPCode_ELB_5XX = "HTTPCode_ELB_5XX_Count"
             HTTPCode_ELB_4XX = "HTTPCode_ELB_4XX_Count"
-        else:
-            LoadBalancerName = None
-            LoadBalancerNameExternal = None
-            LoadBalancerNameInternal = None
-            AWS_ELB = None
-            Latency = None
-            HTTPCode_Backend_5XX = None
-            HTTPCode_Backend_4XX = None
+        elif any(
+            n in res
+            for n in [
+                "LoadBalancerListenerExternal",
+                "LoadBalancerListenerInternal",
+            ]
+        ):
+            # Listener (Rule) only
+            LoadBalancerName = "LoadBalancerListener"
+            AWS_ELB = "AWS/ApplicationELB"
+            Latency = "TargetResponseTime"
+            HTTPCode_Backend_5XX = "HTTPCode_Target_5XX_Count"
+            HTTPCode_Backend_4XX = "HTTPCode_Target_4XX_Count"
 
         # build empty metrics dict from widget_map
         metrics = {n: [] for m in widget_map.values() for n in m}
@@ -495,7 +523,7 @@ def add_stack(istack):
 
             # TargetGroups
             for n, v in res.items():
-                if n.startswith("TargetGroup") and n.endswith(("External", "Internal")):
+                if "TargetGroup" in n and n.endswith(("External", "Internal")):
                     if n.endswith("External"):
                         suffix = "External"
                     else:
@@ -503,11 +531,54 @@ def add_stack(istack):
 
                     tg_name = n.replace("TargetGroup", "")
 
-                    if f"LoadBalancer{suffix}" not in res:
+                    if f"{LoadBalancerName}{suffix}" not in res:
                         continue
                     else:
-                        lb_name = f"LoadBalancer{suffix}"
+                        lb_name = f"{LoadBalancerName}{suffix}"
 
+                    if res[lb_name].startswith("net/"):
+                        AWS_ELB = "AWS/NetworkELB"
+
+                    # Healthy
+                    label = f"{title_role}{L_TYPE} - Healthy"
+                    metrics["healthy"].append(
+                        {
+                            "name": f"Healthy{L_TYPE} {tg_name}",
+                            "label": label,
+                            "metric": [
+                                AWS_ELB,
+                                "HealthyHostCount",
+                                "TargetGroup",
+                                res[n],
+                                "LoadBalancer",
+                                res[lb_name],
+                                {
+                                    "label": label,
+                                    "stat": istack.cfg.statistic,
+                                    "yAxis": "right",
+                                },
+                            ],
+                        }
+                    )
+                    if AWS_ELB == "AWS/NetworkELB":
+                        continue
+                    # Requests
+                    label = f"{title_role} {tg_name} - Requests"
+                    metrics["requests"].append(
+                        {
+                            "name": f"Requests {tg_name}",
+                            "label": label,
+                            "metric": [
+                                AWS_ELB,
+                                "RequestCount",
+                                "TargetGroup",
+                                res[n],
+                                "LoadBalancer",
+                                res[lb_name],
+                                {"label": label, "stat": "Sum"},
+                            ],
+                        }
+                    )
                     # Response Time
                     label = f"Response {tg_name}" f" - {istack.cfg.statisticresponse}"
                     metrics["response"].append(
@@ -515,7 +586,7 @@ def add_stack(istack):
                             "name": f"Response {tg_name}",
                             "label": label,
                             "metric": [
-                                "AWS/ApplicationELB",
+                                AWS_ELB,
                                 "TargetResponseTime",
                                 "TargetGroup",
                                 res[n],
@@ -530,44 +601,6 @@ def add_stack(istack):
                             ],
                         }
                     )
-                    # Healthy
-                    label = f"{title_role}{L_TYPE} - Healthy"
-                    metrics["healthy"].append(
-                        {
-                            "name": f"Healthy{L_TYPE} {tg_name}",
-                            "label": label,
-                            "metric": [
-                                "AWS/ApplicationELB",
-                                "HealthyHostCount",
-                                "TargetGroup",
-                                res[n],
-                                "LoadBalancer",
-                                res[lb_name],
-                                {
-                                    "label": label,
-                                    "stat": istack.cfg.statistic,
-                                    "yAxis": "right",
-                                },
-                            ],
-                        }
-                    )
-                    # Requests
-                    label = f"{title_role} {tg_name} - Requests"
-                    metrics["requests"].append(
-                        {
-                            "name": f"Requests {tg_name}",
-                            "label": label,
-                            "metric": [
-                                "AWS/ApplicationELB",
-                                "RequestCount",
-                                "TargetGroup",
-                                res[n],
-                                "LoadBalancer",
-                                res[lb_name],
-                                {"label": label, "stat": "Sum"},
-                            ],
-                        }
-                    )
                     # 5xx
                     label = f"{title_role} {tg_name} - 5xx"
                     metrics["5xx"].append(
@@ -575,7 +608,7 @@ def add_stack(istack):
                             "name": f"5xx {tg_name}",
                             "label": label,
                             "metric": [
-                                "AWS/ApplicationELB",
+                                AWS_ELB,
                                 "HTTPCode_Target_5XX_Count",
                                 "TargetGroup",
                                 res[n],
@@ -592,7 +625,7 @@ def add_stack(istack):
                             "name": f"4xx {tg_name}",
                             "label": label,
                             "metric": [
-                                "AWS/ApplicationELB",
+                                AWS_ELB,
                                 "HTTPCode_Target_4XX_Count",
                                 "TargetGroup",
                                 res[n],
@@ -602,21 +635,59 @@ def add_stack(istack):
                             ],
                         }
                     )
-        if True:
-            # EC2
-            if all(n in res for n in ["AutoScalingGroupName"]):
-                L_TYPE = " EC2" if IS_MIXED else ""
-                # CPU
-                label = f"Cpu{L_TYPE} - {istack.cfg.statistic}"
+        # EC2
+        if all(n in res for n in ["AutoScalingGroupName"]):
+            L_TYPE = " EC2" if IS_MIXED else ""
+            # CPU
+            label = f"Cpu{L_TYPE} - {istack.cfg.statistic}"
+            metrics["cpu"].append(
+                {
+                    "name": f"Cpu{L_TYPE}",
+                    "label": label,
+                    "metric": [
+                        "AWS/EC2",
+                        "CPUUtilization",
+                        "AutoScalingGroupName",
+                        res["AutoScalingGroupName"],
+                        {
+                            "period": 300,
+                            "stat": istack.cfg.statistic,
+                            "label": label,
+                        },
+                    ],
+                }
+            )
+            # Always add cpu maximum
+            label = f"Cpu{L_TYPE} - Maximum"
+            metrics["cpu"].append(
+                {
+                    "name": f"Cpu{L_TYPE} - Maximum",
+                    "label": label,
+                    "metric": [
+                        "AWS/EC2",
+                        "CPUUtilization",
+                        "AutoScalingGroupName",
+                        res["AutoScalingGroupName"],
+                        {
+                            "period": 300,
+                            "stat": "Maximum",
+                            "label": label,
+                        },
+                    ],
+                }
+            )
+            # CPU Spot
+            if all(n in res for n in ["AutoScalingGroupSpotName"]):
+                label = f"Cpu{L_TYPE} Spot - {istack.cfg.statistic}"
                 metrics["cpu"].append(
                     {
-                        "name": f"Cpu{L_TYPE}",
+                        "name": f"Cpu{L_TYPE} Spot",
                         "label": label,
                         "metric": [
                             "AWS/EC2",
                             "CPUUtilization",
                             "AutoScalingGroupName",
-                            res["AutoScalingGroupName"],
+                            res["AutoScalingGroupSpotName"],
                             {
                                 "period": 300,
                                 "stat": istack.cfg.statistic,
@@ -625,291 +696,278 @@ def add_stack(istack):
                         ],
                     }
                 )
-                # Always add cpu maximum
-                label = f"Cpu{L_TYPE} - Maximum"
-                metrics["cpu"].append(
+            # Healthy
+            label = f"{title_role}{L_TYPE} - Healthy"
+            metrics["healthy"].append(
+                {
+                    "name": f"Healthy{L_TYPE}",
+                    "label": label,
+                    "metric": [
+                        "AWS/AutoScaling",
+                        "GroupInServiceInstances",
+                        "AutoScalingGroupName",
+                        res["AutoScalingGroupName"],
+                        {
+                            "label": label,
+                            "stat": istack.cfg.statistic,
+                            "yAxis": "right",
+                        },
+                    ],
+                }
+            )
+            # Network
+            label = f"{title_role} - NetworkIN"
+            metrics["netin"].append(
+                {
+                    "name": "NetworkIN",
+                    "label": label,
+                    "metric": [
+                        "AWS/EC2",
+                        "NetworkIn",
+                        "AutoScalingGroupName",
+                        res["AutoScalingGroupName"],
+                        {"label": label, "period": 300, "stat": "Sum"},
+                    ],
+                }
+            )
+            label = f"{title_role} - NetworkOUT"
+            metrics["netout"].append(
+                {
+                    "name": "NetworkOUT",
+                    "label": label,
+                    "metric": [
+                        "AWS/EC2",
+                        "NetworkOut",
+                        "AutoScalingGroupName",
+                        res["AutoScalingGroupName"],
+                        {
+                            "label": label,
+                            "period": 300,
+                            "stat": "Sum",
+                            "yAxis": "right",
+                        },
+                    ],
+                }
+            )
+
+        # ELB
+        for n in ["External", "Internal"]:
+            res_name = locals()[f"LoadBalancerName{n}"]
+
+            if res_name in res:
+                if res.get("lb_name", "").startswith("net/"):
+                    # Network LoadBalancer
+                    AWS_ELB = "AWS/NetworkELB"
+                    # Flows
+                    label = f"{title_role} {n} - Flows"
+                    metrics["elb_net_active_flows"].append(
+                        {
+                            "name": f"Flows {n}",
+                            "label": label,
+                            "metric": [
+                                AWS_ELB,
+                                "ActiveFlowCount",
+                                LoadBalancerName,
+                                res[res_name],
+                                {"label": label, "stat": "Average"},
+                            ],
+                        }
+                    )
+                    # Packets
+                    label = f"{title_role} {n} - Bytes"
+                    metrics["elb_net_bytes"].append(
+                        {
+                            "name": f"Packets {n}",
+                            "label": label,
+                            "metric": [
+                                AWS_ELB,
+                                "ProcessedBytes",
+                                LoadBalancerName,
+                                res[res_name],
+                                {"label": label, "stat": "Sum"},
+                            ],
+                        }
+                    )
+                    continue
+                # Response
+                label = f"Response {n} - {istack.cfg.statisticresponse}"
+                metrics["response"].append(
                     {
-                        "name": f"Cpu{L_TYPE} - Maximum",
+                        "name": f"Response {n}",
                         "label": label,
                         "metric": [
-                            "AWS/EC2",
-                            "CPUUtilization",
-                            "AutoScalingGroupName",
-                            res["AutoScalingGroupName"],
+                            AWS_ELB,
+                            Latency,
+                            LoadBalancerName,
+                            res[res_name],
                             {
                                 "period": 300,
-                                "stat": "Maximum",
+                                "stat": istack.cfg.statisticresponse,
+                                "yAxis": "right",
                                 "label": label,
                             },
                         ],
                     }
                 )
-                # CPU Spot
-                if all(n in res for n in ["AutoScalingGroupSpotName"]):
-                    label = f"Cpu{L_TYPE} Spot - {istack.cfg.statistic}"
-                    metrics["cpu"].append(
+                # Requests
+                label = f"{title_role} {n} - Requests"
+                metrics["requests"].append(
+                    {
+                        "name": f"Requests {n}",
+                        "label": label,
+                        "metric": [
+                            AWS_ELB,
+                            "RequestCount",
+                            LoadBalancerName,
+                            res[res_name],
+                            {"label": label, "stat": "Sum"},
+                        ],
+                    }
+                )
+                # 5xx
+                label = f"{title_role} {n} - 5xx"
+                metrics["5xx"].append(
+                    {
+                        "name": f"5xx {n}",
+                        "label": label,
+                        "metric": [
+                            AWS_ELB,
+                            HTTPCode_Backend_5XX,
+                            LoadBalancerName,
+                            res[res_name],
+                            {"label": label, "stat": "Sum"},
+                        ],
+                    }
+                )
+                # 4xx
+                label = f"{title_role} {n} - 4xx"
+                metrics["4xx"].append(
+                    {
+                        "name": f"4xx {n}",
+                        "label": label,
+                        "metric": [
+                            AWS_ELB,
+                            HTTPCode_Backend_4XX,
+                            LoadBalancerName,
+                            res[res_name],
+                            {"label": label, "stat": "Sum", "yAxis": "right"},
+                        ],
+                    }
+                )
+                # 5xx ELB
+                label = f"{title_role} {n} - 5xx"
+                metrics["5xx_elb"].append(
+                    {
+                        "name": f"5xx {n} ELB",
+                        "label": label,
+                        "metric": [
+                            AWS_ELB,
+                            HTTPCode_ELB_5XX,
+                            LoadBalancerName,
+                            res[res_name],
+                            {"label": label, "stat": "Sum"},
+                        ],
+                    }
+                )
+                # 4xx ELB
+                label = f"{title_role} {n} - 4xx"
+                metrics["4xx_elb"].append(
+                    {
+                        "name": f"4xx {n} ELB",
+                        "label": label,
+                        "metric": [
+                            AWS_ELB,
+                            HTTPCode_ELB_4XX,
+                            LoadBalancerName,
+                            res[res_name],
+                            {"label": label, "stat": "Sum", "yAxis": "right"},
+                        ],
+                    }
+                )
+
+                # 50x ELB
+                if f"LoadBalancer{n}" in res:
+                    # 500
+                    label = f"{title_role} {n} - 500"
+                    metrics["500_elb"].append(
                         {
-                            "name": f"Cpu{L_TYPE} Spot",
+                            "name": f"500 {n} ELB",
                             "label": label,
                             "metric": [
-                                "AWS/EC2",
-                                "CPUUtilization",
-                                "AutoScalingGroupName",
-                                res["AutoScalingGroupSpotName"],
+                                AWS_ELB,
+                                "HTTPCode_ELB_500_Count",
+                                "LoadBalancer",
+                                res[res_name],
                                 {
-                                    "period": 300,
-                                    "stat": istack.cfg.statistic,
                                     "label": label,
+                                    "stat": "Sum",
+                                    "yAxis": ("right" if n == "Internal" else "left"),
                                 },
                             ],
                         }
                     )
-                # Healthy
-                label = f"{title_role}{L_TYPE} - Healthy"
-                metrics["healthy"].append(
-                    {
-                        "name": f"Healthy{L_TYPE}",
-                        "label": label,
-                        "metric": [
-                            "AWS/AutoScaling",
-                            "GroupInServiceInstances",
-                            "AutoScalingGroupName",
-                            res["AutoScalingGroupName"],
-                            {
-                                "label": label,
-                                "stat": istack.cfg.statistic,
-                                "yAxis": "right",
-                            },
-                        ],
-                    }
-                )
-                # Network
-                label = f"{title_role} - NetworkIN"
-                metrics["netin"].append(
-                    {
-                        "name": "NetworkIN",
-                        "label": label,
-                        "metric": [
-                            "AWS/EC2",
-                            "NetworkIn",
-                            "AutoScalingGroupName",
-                            res["AutoScalingGroupName"],
-                            {"label": label, "period": 300, "stat": "Sum"},
-                        ],
-                    }
-                )
-                label = f"{title_role} - NetworkOUT"
-                metrics["netout"].append(
-                    {
-                        "name": "NetworkOUT",
-                        "label": label,
-                        "metric": [
-                            "AWS/EC2",
-                            "NetworkOut",
-                            "AutoScalingGroupName",
-                            res["AutoScalingGroupName"],
-                            {
-                                "label": label,
-                                "period": 300,
-                                "stat": "Sum",
-                                "yAxis": "right",
-                            },
-                        ],
-                    }
-                )
-
-            # ELB
-            for n in ["External", "Internal"]:
-                res_name = locals()[f"LoadBalancerName{n}"]
-
-                if res_name in res and "ServiceName" not in res:
-                    # Response
-                    label = f"Response {n} - {istack.cfg.statisticresponse}"
-                    metrics["response"].append(
+                    # 502
+                    label = f"{title_role} {n} - 502"
+                    metrics["502_elb"].append(
                         {
-                            "name": f"Response {n}",
+                            "name": f"502 {n} ELB",
                             "label": label,
                             "metric": [
                                 AWS_ELB,
-                                Latency,
-                                LoadBalancerName,
+                                "HTTPCode_ELB_502_Count",
+                                "LoadBalancer",
                                 res[res_name],
                                 {
-                                    "period": 300,
-                                    "stat": istack.cfg.statisticresponse,
-                                    "yAxis": "right",
                                     "label": label,
+                                    "stat": "Sum",
+                                    "yAxis": ("right" if n == "Internal" else "left"),
                                 },
                             ],
                         }
                     )
-                    # Requests
-                    label = f"{title_role} {n} - Requests"
-                    metrics["requests"].append(
+                    # 503
+                    label = f"{title_role} {n} - 503"
+                    metrics["503_elb"].append(
                         {
-                            "name": f"Requests {n}",
+                            "name": f"503 {n} ELB",
                             "label": label,
                             "metric": [
                                 AWS_ELB,
-                                "RequestCount",
-                                LoadBalancerName,
+                                "HTTPCode_ELB_503_Count",
+                                "LoadBalancer",
                                 res[res_name],
-                                {"label": label, "stat": "Sum"},
+                                {
+                                    "label": label,
+                                    "stat": "Sum",
+                                    "yAxis": ("right" if n == "Internal" else "left"),
+                                },
                             ],
                         }
                     )
-                    # 5xx
-                    label = f"{title_role} {n} - 5xx"
-                    metrics["5xx"].append(
+                    # 504
+                    label = f"{title_role} {n} - 504"
+                    metrics["504_elb"].append(
                         {
-                            "name": f"5xx {n}",
+                            "name": f"504 {n} ELB",
                             "label": label,
                             "metric": [
                                 AWS_ELB,
-                                HTTPCode_Backend_5XX,
-                                LoadBalancerName,
+                                "HTTPCode_ELB_504_Count",
+                                "LoadBalancer",
                                 res[res_name],
-                                {"label": label, "stat": "Sum"},
+                                {
+                                    "label": label,
+                                    "stat": "Sum",
+                                    "yAxis": ("right" if n == "Internal" else "left"),
+                                },
                             ],
                         }
                     )
-                    # 4xx
-                    label = f"{title_role} {n} - 4xx"
-                    metrics["4xx"].append(
-                        {
-                            "name": f"4xx {n}",
-                            "label": label,
-                            "metric": [
-                                AWS_ELB,
-                                HTTPCode_Backend_4XX,
-                                LoadBalancerName,
-                                res[res_name],
-                                {"label": label, "stat": "Sum", "yAxis": "right"},
-                            ],
-                        }
-                    )
-                    # 5xx ELB
-                    label = f"{title_role} {n} - 5xx"
-                    metrics["5xx_elb"].append(
-                        {
-                            "name": f"5xx {n} ELB",
-                            "label": label,
-                            "metric": [
-                                AWS_ELB,
-                                HTTPCode_ELB_5XX,
-                                LoadBalancerName,
-                                res[res_name],
-                                {"label": label, "stat": "Sum"},
-                            ],
-                        }
-                    )
-                    # 4xx ELB
-                    label = f"{title_role} {n} - 4xx"
-                    metrics["4xx_elb"].append(
-                        {
-                            "name": f"4xx {n} ELB",
-                            "label": label,
-                            "metric": [
-                                AWS_ELB,
-                                HTTPCode_ELB_4XX,
-                                LoadBalancerName,
-                                res[res_name],
-                                {"label": label, "stat": "Sum", "yAxis": "right"},
-                            ],
-                        }
-                    )
-
-                    # 50x ELB
-                    if f"LoadBalancer{n}" in res:
-                        # 500
-                        label = f"{title_role} {n} - 500"
-                        metrics["500_elb"].append(
-                            {
-                                "name": f"500 {n} ELB",
-                                "label": label,
-                                "metric": [
-                                    "AWS/ApplicationELB",
-                                    "HTTPCode_ELB_500_Count",
-                                    "LoadBalancer",
-                                    res[res_name],
-                                    {
-                                        "label": label,
-                                        "stat": "Sum",
-                                        "yAxis": (
-                                            "right" if n == "Internal" else "left"
-                                        ),
-                                    },
-                                ],
-                            }
-                        )
-                        # 502
-                        label = f"{title_role} {n} - 502"
-                        metrics["502_elb"].append(
-                            {
-                                "name": f"502 {n} ELB",
-                                "label": label,
-                                "metric": [
-                                    "AWS/ApplicationELB",
-                                    "HTTPCode_ELB_502_Count",
-                                    "LoadBalancer",
-                                    res[res_name],
-                                    {
-                                        "label": label,
-                                        "stat": "Sum",
-                                        "yAxis": (
-                                            "right" if n == "Internal" else "left"
-                                        ),
-                                    },
-                                ],
-                            }
-                        )
-                        # 503
-                        label = f"{title_role} {n} - 503"
-                        metrics["503_elb"].append(
-                            {
-                                "name": f"503 {n} ELB",
-                                "label": label,
-                                "metric": [
-                                    "AWS/ApplicationELB",
-                                    "HTTPCode_ELB_503_Count",
-                                    "LoadBalancer",
-                                    res[res_name],
-                                    {
-                                        "label": label,
-                                        "stat": "Sum",
-                                        "yAxis": (
-                                            "right" if n == "Internal" else "left"
-                                        ),
-                                    },
-                                ],
-                            }
-                        )
-                        # 504
-                        label = f"{title_role} {n} - 504"
-                        metrics["504_elb"].append(
-                            {
-                                "name": f"504 {n} ELB",
-                                "label": label,
-                                "metric": [
-                                    "AWS/ApplicationELB",
-                                    "HTTPCode_ELB_504_Count",
-                                    "LoadBalancer",
-                                    res[res_name],
-                                    {
-                                        "label": label,
-                                        "stat": "Sum",
-                                        "yAxis": (
-                                            "right" if n == "Internal" else "left"
-                                        ),
-                                    },
-                                ],
-                            }
-                        )
 
         return metrics
 
     # get stack resources
-    res = resources.get(istack, dash=True)
+    res = resources.get(istack)
 
     # get widget annotations and widget_annotations_type for alarms threshold
     # or policy tracking target value
@@ -933,20 +991,20 @@ def update(istack):
     resources.set_changed(istack)
     if istack.cfg.dashboard == "OnChange":
         res_changed = istack.changed["resources"]
-        mode = ""
     elif istack.cfg.dashboard in ["Always", "Generic"]:
         res_changed = istack.after["resources"]
-        mode = istack.cfg.dashboard
     else:
         return
 
     if res_changed or any(
-        n in istack.changed["outputs"]
-        for n in [
-            "ScalingPolicyTrackings",
-            "AutoScalingScalingPolicy",
-            "ApplicationAutoScalingScalingPolicy",
-        ]
+        n.startswith(
+            (
+                "ScalingPolicyTrackings",
+                "AutoScalingScalingPolicy",
+                "ApplicationAutoScalingScalingPolicy",
+            )
+        )
+        for n in istack.changed["outputs"]
     ):
         for dash in response_dash["DashboardEntries"]:
             if istack.name in dash["DashboardName"]:
