@@ -1,5 +1,6 @@
 import argparse
-from . import cfg
+
+from . import cfg, __version__
 from .commands import (
     create,
     update,
@@ -52,13 +53,13 @@ def get_update_parser(subparser, parents=[]):
     parser.add_argument(
         "-n", "--nochangeset", help="No ChangeSet", required=False, action="store_true"
     )
-    parser.add_argument(
-        "-C",
-        "--changeset-original",
-        help="Do not simply ChangeSet",
-        required=False,
-        action="store_true",
-    )
+    #    parser.add_argument(
+    #        "-C",
+    #        "--changeset-original",
+    #        help="Do not simply ChangeSet",
+    #        required=False,
+    #        action="store_true",
+    #    )
     parser.add_argument("--dryrun", help="Show changeset and exit", action="store_true")
     parser.add_argument(
         "-T", "--showtags", help="Show tags changes in changeset", action="store_true"
@@ -108,13 +109,22 @@ def set_dash_parser(subparser, parents=[]):
         const=True,
         default=False,
     )
+    parser.add_argument(
+        "--dash-force",
+        help="Overwrite existing dash (remove all previous data!)",
+        action="store_true",
+    )
 
 
 def get_show_parser(subparser, parents=[]):
     parser = subparser.add_parser("show", parents=parents, help="Show Stacks table")
 
     parser.add_argument(
-        "-F", "--fields", nargs="+", type=str, default=cfg.SHOW_TABLE_FIELDS,
+        "-F",
+        "--fields",
+        nargs="+",
+        type=str,
+        default=cfg.SHOW_TABLE_FIELDS,
         help="Can use syntax 'Name=DisplayName' to use custom table heading",
     )
     parser.add_argument(
@@ -168,7 +178,7 @@ def set_stackset_parser(subparser, parents=[]):
     )
 
     # update parser
-    parser_update = stackset_parser.add_parser(
+    stackset_parser.add_parser(
         "update",
         parents=parents
         + [
@@ -178,7 +188,7 @@ def set_stackset_parser(subparser, parents=[]):
     )
 
     # info parser
-    parser_info = stackset_parser.add_parser(
+    stackset_parser.add_parser(
         "info",
         parents=[
             get_stackset_single_parser(),
@@ -187,7 +197,7 @@ def set_stackset_parser(subparser, parents=[]):
     )
 
     # parameters parser
-    parser_parameters = stackset_parser.add_parser(
+    stackset_parser.add_parser(
         "parameters",
         parents=[
             get_stackset_single_parser(),
@@ -196,7 +206,7 @@ def set_stackset_parser(subparser, parents=[]):
     )
 
     # show parser
-    parser_show = get_show_parser(
+    get_show_parser(
         stackset_parser,
         [
             get_stackset_single_parser(),
@@ -204,7 +214,7 @@ def set_stackset_parser(subparser, parents=[]):
     )
 
     # instances parser
-    parser_instances = stackset_parser.add_parser(
+    stackset_parser.add_parser(
         "instances",
         parents=[
             get_stackset_single_parser(),
@@ -234,7 +244,7 @@ def set_replicate_parser(subparser, parents=[]):
     )
 
     # replicate create
-    parser_create = get_create_parser(
+    get_create_parser(
         replicate_parser,
         parents
         + [
@@ -246,7 +256,7 @@ def set_replicate_parser(subparser, parents=[]):
     )
 
     # replicate update
-    parser_update = get_update_parser(
+    get_update_parser(
         replicate_parser,
         parents
         + [
@@ -258,16 +268,14 @@ def set_replicate_parser(subparser, parents=[]):
     )
 
     # replicate delete
-    parser_delete = replicate_parser.add_parser(
+    replicate_parser.add_parser(
         "delete",
         parents=parents + [get_stack_single_parser(), regions_parser],
         help="Delete Stack (WARNING)",
     )
 
     # replicate show
-    parser_show = get_show_parser(
-        replicate_parser, [get_stack_selection_parser(), regions_parser]
-    )
+    get_show_parser(replicate_parser, [get_stack_selection_parser(), regions_parser])
 
 
 def set_r53_parser(subparser, parents=[]):
@@ -279,6 +287,9 @@ def set_r53_parser(subparser, parents=[]):
     parser.set_defaults(func=r53)
 
     parser.add_argument("--dryrun", help="Show changes and exit", action="store_true")
+    parser.add_argument(
+        "--safe", help="Create only internal and regional records", action="store_true"
+    )
     parser.add_argument(
         "--noorigin", help="Do not create Origin Record", action="store_true"
     )
@@ -390,7 +401,7 @@ def get_create_update_parser():
     parser.add_argument(
         "--tags",
         nargs="+",
-        help="Tags, space separated, to associate with this stack. Use syntax: Key=Value",
+        help="Tags, space separated, to associate with this stack. Use syntax: Key=Value (use REMOVE as Value to remove tag)",
         type=str,
         default=[],
     )
@@ -423,13 +434,18 @@ def get_parser():
         "0 for interactive - valid only for jobs=1",
         type=int,
     )
+    parser.add_argument(
+        "-m",
+        "--msg-topic",
+        help="AWS SNS Topic used by Amazon Q to send messages to Slack/Teams configured channels",
+    )
 
     # action parser
     action_parser = argparse.ArgumentParser(add_help=False)
 
     action_parser.add_argument(
         "-y",
-        "--answer_yes",
+        "--answer-yes",
         help="Answer YES (No Confirm)",
         required=False,
         action="store_true",
@@ -441,14 +457,6 @@ def get_parser():
         required=False,
         action="store_true",
     )
-    action_parser.add_argument(
-        "-c",
-        "--slack_channel",
-        help=f"Slack Channel [{cfg.SLACK_CHANNEL}]",
-        nargs="?",
-        const=cfg.SLACK_CHANNEL,
-        default=False,
-    )
 
     # template parser
     template_parser_create = get_template_parser()
@@ -629,6 +637,9 @@ def get_parser():
         ],
     )
 
+    # iboxstacksops version parser
+    command_subparser.add_parser("version", help="Show version and exit")
+
     return parser
 
 
@@ -636,6 +647,10 @@ def set_cfg(argv):
     parser = get_parser()
     args = parser.parse_known_args(argv)
 
+    if args[0].command == "version":
+        print(__version__)
+        exit(0)
+
     for n, v in vars(args[0]).items():
         setattr(cfg, n, v)
 
