@@ -1,9 +1,11 @@
 import time
+import sys
 import concurrent.futures
+from pprint import pformat
 from traceback import print_exc
+
+from . import logger, tqdm, cfg, IboxError
 from .aws import myboto3
-from . import cfg
-from .common import *
 
 
 def show_confirm():
@@ -39,6 +41,7 @@ def concurrent_exec(command, stacks, smodule, region=None, **kwargs):
         return
 
     cfg.parallel = False if not cfg.parallel and jobs == 1 else True
+    use_pbar = True if len(stacks) > 1 else False
 
     with concurrent.futures.ThreadPoolExecutor(max_workers=jobs) as executor:
         future_to_stack = {}
@@ -52,21 +55,31 @@ def concurrent_exec(command, stacks, smodule, region=None, **kwargs):
                 if _pause_or_stop():
                     do_exit = True
                     break
+        pbar = tqdm(
+            concurrent.futures.as_completed(future_to_stack),
+            total=len(future_to_stack),
+            desc="Processing Stacks",
+            disable=False if use_pbar else True,
+        )
 
-        for future in concurrent.futures.as_completed(future_to_stack):
+        for future in pbar:
             stack = future_to_stack[future]
             try:
                 data[stack] = future.result()
             except IboxError as e:
                 data[stack] = e.args[0]
                 n_failed += 1
+                if use_pbar:
+                    pbar.set_postfix(failed=n_failed)
             except Exception as e:
                 print(f"{stack} generated an exception: {e}")
                 print_exc()
                 raise IboxError(e)
 
     if n_failed == len(stacks):
-        raise IboxError(f"All failed:\n{data}")
+        if n_failed > 1:
+            logger.error("All Stacks Failed!")
+        raise IboxError(pformat(data))
 
     if do_exit:
         print(data)
